Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

### Earth-Ref Magic Builder Help Window

- Check and fill in information for er_locations
  - Fill location type (under the header location_type).
    Use controlled vocabularies from `location type controlled vocabularies`. If you cant find any appropriate definition use: Not Specified.
  - Er_citations should be a colon-delimited list starting with "This study" and including the DOIs for any additional citations. (see Digital Object Identification)